@@ -270,24 +270,22 @@ class Word2VecModel(TransformerMixin, BaseEstimator):
 
     def infer_single_token(
         self,
-        model: Word2Vec,
         token: str,
     ) -> Optional[np.ndarray]:
         """
         Use the trained Word2Vec to infer the vector of a single token.
         If the token is unknown it returns an empty numpy array.
         """
-        return model.wv[token] if token in model.wv else np.array([])
+        return self.model.wv[token] if token in self.model.wv else np.array([])
 
     def infer_list_of_tokens(
         self,
-        model: Word2Vec,
         tokens: List[str],
     ) -> List[np.ndarray]:
         """
         If the word vectors of multiple token in a document.
         """
-        return [self.infer_single_token(model, token) for token in tokens if token]
+        return [self.infer_single_token(token) for token in tokens if token]
 
     def mean_of_vector_list(
         self,
@@ -310,7 +308,7 @@ class Word2VecModel(TransformerMixin, BaseEstimator):
                 "This model has not been fitted yet. Call 'fit' with appropriate arguments before using this method."
             )
 
-        word_tokens = [self.infer_list_of_tokens(self.model, tokens) for tokens in X]
+        word_tokens = [self.infer_list_of_tokens(tokens) for tokens in X]
 
         # Calculate the mean vector of all tokens in each document
         if self.mean_vector:
